-- =============================================
-- Application: Excel Applications. 10 Steps for Database Developers
-- Developer:   Sergey Vaselenko
-- Release:     1.0, 2017-03-20
-- =============================================
GO

-- Install the SaveToDB Framework first
GO

CREATE SCHEMA [dbo67] AUTHORIZATION [dbo]
GO

CREATE TABLE [dbo67].[Accounts] (
      [ID] int IDENTITY(1,1) NOT NULL
    , [Name] nvarchar(50) NOT NULL
    , CONSTRAINT [PK_Accounts_dbo67] PRIMARY KEY ([ID])
    , CONSTRAINT [IX_Accounts_dbo67] UNIQUE ([Name])
)
GO

CREATE TABLE [dbo67].[Companies] (
      [ID] int IDENTITY(1,1) NOT NULL
    , [Name] nvarchar(50) NOT NULL
    , CONSTRAINT [PK_Companies_dbo67] PRIMARY KEY ([ID])
    , CONSTRAINT [IX_Companies_dbo67] UNIQUE ([Name])
)
GO

CREATE TABLE [dbo67].[Items] (
      [ID] int IDENTITY(1,1) NOT NULL
    , [Name] nvarchar(50) NOT NULL
    , CONSTRAINT [PK_Items_dbo67] PRIMARY KEY ([ID])
    , CONSTRAINT [IX_Items_dbo67] UNIQUE ([Name])
)
GO

CREATE TABLE [dbo67].[Payments] (
      [ID] int IDENTITY(1,1) NOT NULL
    , [Date] datetime NULL
    , [Sum] money NULL
    , [AccountID] int NULL
    , [CompanyID] int NULL
    , [ItemID] int NULL
    , [Comment] nvarchar(255) NULL
    , CONSTRAINT [PK_Payments_dbo67] PRIMARY KEY ([ID])
)
GO

ALTER TABLE [dbo67].[Payments] ADD CONSTRAINT [FK_Payments_Accounts_dbo67] FOREIGN KEY ([AccountID]) REFERENCES [dbo67].[Accounts] ([ID]) ON UPDATE CASCADE
GO

ALTER TABLE [dbo67].[Payments] ADD CONSTRAINT [FK_Payments_Companies_dbo67] FOREIGN KEY ([CompanyID]) REFERENCES [dbo67].[Companies] ([ID]) ON UPDATE CASCADE
GO

ALTER TABLE [dbo67].[Payments] ADD CONSTRAINT [FK_Payments_Items_dbo67] FOREIGN KEY ([ItemID]) REFERENCES [dbo67].[Items] ([ID]) ON UPDATE CASCADE
GO

-- =============================================
-- Author:      Sergey Vaselenko
-- Release:     1.0, 2017-03-20
-- Description: Payments view
-- =============================================

CREATE VIEW [dbo67].[viewPayments]
AS

SELECT
    p.ID
    , p.[Date]
    , p.[Sum]
    , p.AccountID
    , p.CompanyID
    , p.ItemID
    , p.Comment
    
FROM
    dbo67.Payments p


GO

-- =============================================
-- Author:      Sergey Vaselenko
-- Release:     1.0, 2017-03-20
-- Description: Payments stored procedure
-- =============================================

CREATE PROCEDURE [dbo67].[uspPayments]
    @AccountID int = NULL
    , @CompanyID int = NULL
    , @ItemID int = NULL
AS
BEGIN

SET NOCOUNT ON
   
SELECT
    p.ID
    , p.[Date]
    , p.[Sum]
    , p.AccountID
    , p.CompanyID
    , p.ItemID
    , p.Comment
    
FROM
    dbo67.Payments p
WHERE
    COALESCE(@AccountID, p.AccountID, 0) = COALESCE(p.AccountID, 0)
    AND COALESCE(@CompanyID, p.CompanyID, 0) = COALESCE(p.CompanyID, 0)
    AND COALESCE(@ItemID, p.ItemID, 0) = COALESCE(p.ItemID, 0)
    
END


GO

CREATE PROCEDURE [dbo67].[uspPayments_delete]
    @ID int
AS
BEGIN

SET NOCOUNT ON

DELETE dbo67.Payments
WHERE
    ID = @ID

END


GO

CREATE PROCEDURE [dbo67].[uspPayments_insert]
    @Date datetime = NULL
    , @Sum money = NULL
    , @AccountID int = NULL
    , @CompanyID int = NULL
    , @ItemID int = NULL
    , @Comment nvarchar(255) = NULL
AS
BEGIN

SET NOCOUNT ON

INSERT INTO dbo67.Payments
    ( [Date]
    , [Sum]
    , AccountID
    , CompanyID
    , ItemID
    , Comment
    )
VALUES
    ( @Date
    , @Sum
    , @AccountID
    , @CompanyID
    , @ItemID
    , @Comment
    )

END


GO

CREATE PROCEDURE [dbo67].[uspPayments_update]
      @ID int
    , @Date datetime = NULL
    , @Sum money = NULL
    , @AccountID int = NULL
    , @CompanyID int = NULL
    , @ItemID int = NULL
    , @Comment nvarchar(255) = NULL
AS
BEGIN
    
SET NOCOUNT ON

UPDATE dbo67.Payments
SET
    [Date] = @Date
    , [Sum] = @Sum
    , AccountID = @AccountID
    , CompanyID = @CompanyID
    , ItemID = @ItemID
    , Comment = @Comment
WHERE
    ID = @ID

END


GO


INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME]) VALUES (N'dbo67', N'Payments', N'AccountID', N'en', N'Account');
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME]) VALUES (N'dbo67', N'Payments', N'CompanyID', N'en', N'Company');
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME]) VALUES (N'dbo67', N'Payments', N'ItemID', N'en', N'Item');
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME]) VALUES (N'dbo67', N'uspPayments', N'AccountID', N'en', N'Account');
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME]) VALUES (N'dbo67', N'uspPayments', N'CompanyID', N'en', N'Company');
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME]) VALUES (N'dbo67', N'uspPayments', N'ItemID', N'en', N'Item');
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME]) VALUES (N'dbo67', N'viewPayments', N'AccountID', N'en', N'Account');
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME]) VALUES (N'dbo67', N'viewPayments', N'CompanyID', N'en', N'Company');
INSERT INTO [dbo01].[ColumnTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME]) VALUES (N'dbo67', N'viewPayments', N'ItemID', N'en', N'Item');
GO

INSERT INTO [dbo01].[EventHandlers] ([TABLE_SCHEMA], [TABLE_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [IS_ACTIVE]) VALUES (N'dbo67', N'Payments', N'Actions', N'dbo67', N'Instruction', N'HTTP', N'https://www.savetodb.com', 1);
INSERT INTO [dbo01].[EventHandlers] ([TABLE_SCHEMA], [TABLE_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [IS_ACTIVE]) VALUES (N'dbo67', N'uspPayments', N'Actions', N'dbo67', N'Instruction', N'HTTP', N'https://www.savetodb.com', 1);
INSERT INTO [dbo01].[EventHandlers] ([TABLE_SCHEMA], [TABLE_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [IS_ACTIVE]) VALUES (N'dbo67', N'viewPayments', N'Actions', N'dbo67', N'Instruction', N'HTTP', N'https://www.savetodb.com', 1);
INSERT INTO [dbo01].[EventHandlers] ([TABLE_SCHEMA], [TABLE_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [TARGET_WORKSHEET], [IS_ACTIVE]) VALUES (N'dbo67', N'Payments', N'ContextMenu', N'dbo67', N'Company Payments', N'CODE', N'SELECT
    p.[Date]
    , p.[Sum]
    , c.Name AS Company
    , i.Name AS Item
    , p.Comment
FROM
    dbo67.Payments p
    LEFT OUTER JOIN dbo67.Items i ON i.ID = p.ItemID
    INNER JOIN dbo67.Companies c ON c.ID = p.CompanyID
WHERE
    p.CompanyID = @CompanyID', N'_TaskPane', 1);
INSERT INTO [dbo01].[EventHandlers] ([TABLE_SCHEMA], [TABLE_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [TARGET_WORKSHEET], [IS_ACTIVE]) VALUES (N'dbo67', N'Payments', N'ContextMenu', N'dbo67', N'Item Payments', N'CODE', N'SELECT
    p.[Date]
    , p.[Sum]
    , c.Name AS Company
    , i.Name AS Item
    , p.Comment
FROM
    dbo67.Payments p
    INNER JOIN dbo67.Items i ON i.ID = p.ItemID
    LEFT OUTER JOIN dbo67.Companies c ON c.ID = p.CompanyID
WHERE
    p.ItemID = @ItemID', N'_TaskPane', 1);
INSERT INTO [dbo01].[EventHandlers] ([TABLE_SCHEMA], [TABLE_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [TARGET_WORKSHEET], [IS_ACTIVE]) VALUES (N'dbo67', N'uspPayments', N'SelectionChange', N'dbo67', N'Company Payments', N'CODE', N'SELECT
    p.[Date]
    , p.[Sum]
    , c.Name AS Company
    , i.Name AS Item
    , p.Comment
FROM
    dbo67.Payments p
    LEFT OUTER JOIN dbo67.Items i ON i.ID = p.ItemID
    INNER JOIN dbo67.Companies c ON c.ID = p.CompanyID
WHERE
    p.CompanyID = @CompanyID', N'_TaskPane', 1);
INSERT INTO [dbo01].[EventHandlers] ([TABLE_SCHEMA], [TABLE_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [TARGET_WORKSHEET], [IS_ACTIVE]) VALUES (N'dbo67', N'uspPayments', N'SelectionChange', N'dbo67', N'Item Payments', N'CODE', N'SELECT
    p.[Date]
    , p.[Sum]
    , c.Name AS Company
    , i.Name AS Item
    , p.Comment
FROM
    dbo67.Payments p
    INNER JOIN dbo67.Items i ON i.ID = p.ItemID
    LEFT OUTER JOIN dbo67.Companies c ON c.ID = p.CompanyID
WHERE
    p.ItemID = @ItemID', N'_TaskPane', 1);
INSERT INTO [dbo01].[EventHandlers] ([TABLE_SCHEMA], [TABLE_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [TARGET_WORKSHEET], [IS_ACTIVE]) VALUES (N'dbo67', N'viewPayments', N'SelectionChange', N'dbo67', N'Company Payments', N'CODE', N'SELECT
    p.[Date]
    , p.[Sum]
    , c.Name AS Company
    , i.Name AS Item
    , p.Comment
FROM
    dbo67.Payments p
    LEFT OUTER JOIN dbo67.Items i ON i.ID = p.ItemID
    INNER JOIN dbo67.Companies c ON c.ID = p.CompanyID
WHERE
    p.CompanyID = @CompanyID', N' ', 1);
INSERT INTO [dbo01].[EventHandlers] ([TABLE_SCHEMA], [TABLE_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [TARGET_WORKSHEET], [IS_ACTIVE]) VALUES (N'dbo67', N'viewPayments', N'SelectionChange', N'dbo67', N'Item Payments', N'CODE', N'SELECT
    p.[Date]
    , p.[Sum]
    , c.Name AS Company
    , i.Name AS Item
    , p.Comment
FROM
    dbo67.Payments p
    INNER JOIN dbo67.Items i ON i.ID = p.ItemID
    LEFT OUTER JOIN dbo67.Companies c ON c.ID = p.CompanyID
WHERE
    p.ItemID = @ItemID', N' ', 1);
INSERT INTO [dbo01].[EventHandlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [IS_ACTIVE]) VALUES (N'dbo67', N'Payments', N'AccountID', N'ValidationList', N'dbo67', N'Accounts', N'TABLE', N'ID,Name', 1);
INSERT INTO [dbo01].[EventHandlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [IS_ACTIVE]) VALUES (N'dbo67', N'Payments', N'CompanyID', N'ValidationList', N'dbo67', N'Companies', N'TABLE', N'ID,Name', 1);
INSERT INTO [dbo01].[EventHandlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [IS_ACTIVE]) VALUES (N'dbo67', N'Payments', N'ItemID', N'ValidationList', N'dbo67', N'Items', N'TABLE', N'ID,Name', 1);
INSERT INTO [dbo01].[EventHandlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [IS_ACTIVE]) VALUES (N'dbo67', N'uspPayments', N'AccountID', N'ValidationList', N'dbo67', N'Accounts', N'TABLE', N'ID,Name', 1);
INSERT INTO [dbo01].[EventHandlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [IS_ACTIVE]) VALUES (N'dbo67', N'uspPayments', N'CompanyID', N'ValidationList', N'dbo67', N'Companies', N'TABLE', N'ID,Name', 1);
INSERT INTO [dbo01].[EventHandlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [IS_ACTIVE]) VALUES (N'dbo67', N'uspPayments', N'ItemID', N'ValidationList', N'dbo67', N'Items', N'TABLE', N'ID,Name', 1);
INSERT INTO [dbo01].[EventHandlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [IS_ACTIVE]) VALUES (N'dbo67', N'viewPayments', N'AccountID', N'ValidationList', N'dbo67', N'Accounts', N'TABLE', N'ID,Name', 1);
INSERT INTO [dbo01].[EventHandlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [IS_ACTIVE]) VALUES (N'dbo67', N'viewPayments', N'CompanyID', N'ValidationList', N'dbo67', N'Companies', N'TABLE', N'ID,Name', 1);
INSERT INTO [dbo01].[EventHandlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [IS_ACTIVE]) VALUES (N'dbo67', N'viewPayments', N'ItemID', N'ValidationList', N'dbo67', N'Items', N'TABLE', N'ID,Name', 1);
GO

INSERT INTO [dbo01].[ObjectTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME]) VALUES (N'dbo67', N'Accounts', N'en', N'Accounts');
INSERT INTO [dbo01].[ObjectTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME]) VALUES (N'dbo67', N'Companies', N'en', N'Companies');
INSERT INTO [dbo01].[ObjectTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME]) VALUES (N'dbo67', N'Items', N'en', N'Items');
INSERT INTO [dbo01].[ObjectTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME]) VALUES (N'dbo67', N'Payments', N'en', N'Payments');
INSERT INTO [dbo01].[ObjectTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME]) VALUES (N'dbo67', N'uspPayments', N'en', N'Payments (sp)');
INSERT INTO [dbo01].[ObjectTranslation] ([TABLE_SCHEMA], [TABLE_NAME], [LANGUAGE_NAME], [TRANSLATED_NAME]) VALUES (N'dbo67', N'viewPayments', N'en', N'Payments (view)');
GO

INSERT INTO [dbo01].[ParameterValues] ([TABLE_SCHEMA], [TABLE_NAME], [PARAMETER_NAME], [SELECT_SCHEMA], [SELECT_NAME], [SELECT_TYPE], [SELECT_CODE]) VALUES (N'dbo67', N'uspPayments', N'AccountID', N'dbo67', N'Accounts', N'TABLE', N'ID,Name');
INSERT INTO [dbo01].[ParameterValues] ([TABLE_SCHEMA], [TABLE_NAME], [PARAMETER_NAME], [SELECT_SCHEMA], [SELECT_NAME], [SELECT_TYPE], [SELECT_CODE]) VALUES (N'dbo67', N'uspPayments', N'CompanyID', N'dbo67', N'Companies', N'TABLE', N'ID,Name');
INSERT INTO [dbo01].[ParameterValues] ([TABLE_SCHEMA], [TABLE_NAME], [PARAMETER_NAME], [SELECT_SCHEMA], [SELECT_NAME], [SELECT_TYPE], [SELECT_CODE]) VALUES (N'dbo67', N'uspPayments', N'ItemID', N'dbo67', N'Items', N'TABLE', N'ID,Name');
GO

INSERT INTO [dbo01].[QueryList] ([TABLE_SCHEMA], [TABLE_NAME], [TABLE_TYPE], [INSERT_PROCEDURE], [UPDATE_PROCEDURE], [DELETE_PROCEDURE], [PROCEDURE_TYPE]) VALUES (N'dbo67', N'uspPayments', N'PROCEDURE', N'dbo67.uspPayments_insert', N'dbo67.uspPayments_update', N'dbo67.uspPayments_delete', N'PROCEDURE');
GO

INSERT INTO [dbo01].[TableFormats] ([TABLE_SCHEMA], [TABLE_NAME], [TABLE_EXCEL_FORMAT_XML]) VALUES (N'dbo67', N'Accounts', '<table name="dbo67.Accounts"><columnFormats><column name="" property="ListObjectName" value="Accounts_Table1" type="String"/><column name="" property="ShowTotals" value="False" type="Boolean"/><column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String"/><column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean"/><column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean"/><column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean"/><column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean"/><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean"/><column name="_RowNum" property="Address" value="$B$4" type="String"/><column name="_RowNum" property="NumberFormat" value="General" type="String"/><column name="ID" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="ID" property="Address" value="$C$4" type="String"/><column name="ID" property="ColumnWidth" value="4.43" type="Double"/><column name="ID" property="NumberFormat" value="General" type="String"/><column name="ID" property="Validation.Type" value="1" type="Double"/><column name="ID" property="Validation.Operator" value="1" type="Double"/><column name="ID" property="Validation.Formula1" value="-2147483648" type="String"/><column name="ID" property="Validation.Formula2" value="2147483647" type="String"/><column name="ID" property="Validation.AlertStyle" value="1" type="Double"/><column name="ID" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="ID" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="ID" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="ID" property="Validation.ErrorMessage" value="The column requires values of the int datatype." type="String"/><column name="ID" property="Validation.ShowInput" value="True" type="Boolean"/><column name="ID" property="Validation.ShowError" value="True" type="Boolean"/><column name="Name" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="Name" property="Address" value="$D$4" type="String"/><column name="Name" property="ColumnWidth" value="7.86" type="Double"/><column name="Name" property="NumberFormat" value="General" type="String"/><column name="Name" property="Validation.Type" value="6" type="Double"/><column name="Name" property="Validation.Operator" value="8" type="Double"/><column name="Name" property="Validation.Formula1" value="50" type="String"/><column name="Name" property="Validation.AlertStyle" value="1" type="Double"/><column name="Name" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="Name" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="Name" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="Name" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(50) datatype." type="String"/><column name="Name" property="Validation.ShowInput" value="True" type="Boolean"/><column name="Name" property="Validation.ShowError" value="True" type="Boolean"/><column name="Name" property="FormatConditions(1).AppliesTo.Address" value="$D$4" type="String"/><column name="Name" property="FormatConditions(1).Type" value="2" type="Double"/><column name="Name" property="FormatConditions(1).Priority" value="1" type="Double"/><column name="Name" property="FormatConditions(1).Formula1" value="=ISBLANK(D4)" type="String"/><column name="Name" property="FormatConditions(1).Interior.Color" value="65535" type="Double"/><column name="Name" property="FormatConditions(1).Interior.ThemeColor" value="0" type="Double"/><column name="Name" property="FormatConditions(1).Interior.TintAndShade" value="0" type="Double"/><column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean"/><column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean"/><column name="" property="ActiveWindow.Split" value="True" type="Boolean"/><column name="" property="ActiveWindow.SplitRow" value="0" type="Double"/><column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double"/><column name="" property="PageSetup.Orientation" value="1" type="Double"/><column name="" property="PageSetup.FitToPagesWide" value="1" type="Double"/><column name="" property="PageSetup.FitToPagesTall" value="1" type="Double"/></columnFormats></table>');
INSERT INTO [dbo01].[TableFormats] ([TABLE_SCHEMA], [TABLE_NAME], [TABLE_EXCEL_FORMAT_XML]) VALUES (N'dbo67', N'Companies', '<table name="dbo67.Companies"><columnFormats><column name="" property="ListObjectName" value="Sheet1_Table1" type="String"/><column name="" property="ShowTotals" value="False" type="Boolean"/><column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String"/><column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean"/><column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean"/><column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean"/><column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean"/><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean"/><column name="_RowNum" property="Address" value="$B$4" type="String"/><column name="_RowNum" property="NumberFormat" value="General" type="String"/><column name="ID" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="ID" property="Address" value="$C$4" type="String"/><column name="ID" property="ColumnWidth" value="4.43" type="Double"/><column name="ID" property="NumberFormat" value="General" type="String"/><column name="ID" property="Validation.Type" value="1" type="Double"/><column name="ID" property="Validation.Operator" value="1" type="Double"/><column name="ID" property="Validation.Formula1" value="-2147483648" type="String"/><column name="ID" property="Validation.Formula2" value="2147483647" type="String"/><column name="ID" property="Validation.AlertStyle" value="1" type="Double"/><column name="ID" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="ID" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="ID" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="ID" property="Validation.ErrorMessage" value="The column requires values of the int datatype." type="String"/><column name="ID" property="Validation.ShowInput" value="True" type="Boolean"/><column name="ID" property="Validation.ShowError" value="True" type="Boolean"/><column name="Name" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="Name" property="Address" value="$D$4" type="String"/><column name="Name" property="ColumnWidth" value="15.57" type="Double"/><column name="Name" property="NumberFormat" value="General" type="String"/><column name="Name" property="Validation.Type" value="6" type="Double"/><column name="Name" property="Validation.Operator" value="8" type="Double"/><column name="Name" property="Validation.Formula1" value="50" type="String"/><column name="Name" property="Validation.AlertStyle" value="1" type="Double"/><column name="Name" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="Name" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="Name" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="Name" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(50) datatype." type="String"/><column name="Name" property="Validation.ShowInput" value="True" type="Boolean"/><column name="Name" property="Validation.ShowError" value="True" type="Boolean"/><column name="Name" property="FormatConditions(1).AppliesTo.Address" value="$D$4:$D$11" type="String"/><column name="Name" property="FormatConditions(1).Type" value="2" type="Double"/><column name="Name" property="FormatConditions(1).Priority" value="1" type="Double"/><column name="Name" property="FormatConditions(1).Formula1" value="=ISBLANK(D4)" type="String"/><column name="Name" property="FormatConditions(1).Interior.Color" value="65535" type="Double"/><column name="Name" property="FormatConditions(1).Interior.ThemeColor" value="0" type="Double"/><column name="Name" property="FormatConditions(1).Interior.TintAndShade" value="0" type="Double"/><column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean"/><column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean"/><column name="" property="ActiveWindow.Split" value="True" type="Boolean"/><column name="" property="ActiveWindow.SplitRow" value="0" type="Double"/><column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double"/><column name="" property="PageSetup.Orientation" value="1" type="Double"/><column name="" property="PageSetup.FitToPagesWide" value="1" type="Double"/><column name="" property="PageSetup.FitToPagesTall" value="1" type="Double"/></columnFormats></table>');
INSERT INTO [dbo01].[TableFormats] ([TABLE_SCHEMA], [TABLE_NAME], [TABLE_EXCEL_FORMAT_XML]) VALUES (N'dbo67', N'Items', '<table name="dbo67.Items"><columnFormats><column name="" property="ListObjectName" value="Table_ExternalData_1" type="String"/><column name="" property="ShowTotals" value="False" type="Boolean"/><column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String"/><column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean"/><column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean"/><column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean"/><column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean"/><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean"/><column name="_RowNum" property="Address" value="$B$4" type="String"/><column name="_RowNum" property="NumberFormat" value="General" type="String"/><column name="ID" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="ID" property="Address" value="$C$4" type="String"/><column name="ID" property="ColumnWidth" value="4.43" type="Double"/><column name="ID" property="NumberFormat" value="General" type="String"/><column name="ID" property="Validation.Type" value="1" type="Double"/><column name="ID" property="Validation.Operator" value="1" type="Double"/><column name="ID" property="Validation.Formula1" value="-2147483648" type="String"/><column name="ID" property="Validation.Formula2" value="2147483647" type="String"/><column name="ID" property="Validation.AlertStyle" value="1" type="Double"/><column name="ID" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="ID" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="ID" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="ID" property="Validation.ErrorMessage" value="The column requires values of the int datatype." type="String"/><column name="ID" property="Validation.ShowInput" value="True" type="Boolean"/><column name="ID" property="Validation.ShowError" value="True" type="Boolean"/><column name="Name" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="Name" property="Address" value="$D$4" type="String"/><column name="Name" property="ColumnWidth" value="8.57" type="Double"/><column name="Name" property="NumberFormat" value="General" type="String"/><column name="Name" property="Validation.Type" value="6" type="Double"/><column name="Name" property="Validation.Operator" value="8" type="Double"/><column name="Name" property="Validation.Formula1" value="50" type="String"/><column name="Name" property="Validation.AlertStyle" value="1" type="Double"/><column name="Name" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="Name" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="Name" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="Name" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(50) datatype." type="String"/><column name="Name" property="Validation.ShowInput" value="True" type="Boolean"/><column name="Name" property="Validation.ShowError" value="True" type="Boolean"/><column name="Name" property="FormatConditions(1).AppliesTo.Address" value="$D$4:$D$7" type="String"/><column name="Name" property="FormatConditions(1).Type" value="2" type="Double"/><column name="Name" property="FormatConditions(1).Priority" value="1" type="Double"/><column name="Name" property="FormatConditions(1).Formula1" value="=ISBLANK(D4)" type="String"/><column name="Name" property="FormatConditions(1).Interior.Color" value="65535" type="Double"/><column name="Name" property="FormatConditions(1).Interior.ThemeColor" value="0" type="Double"/><column name="Name" property="FormatConditions(1).Interior.TintAndShade" value="0" type="Double"/><column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean"/><column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean"/><column name="" property="ActiveWindow.Split" value="True" type="Boolean"/><column name="" property="ActiveWindow.SplitRow" value="0" type="Double"/><column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double"/><column name="" property="PageSetup.Orientation" value="1" type="Double"/><column name="" property="PageSetup.FitToPagesWide" value="1" type="Double"/><column name="" property="PageSetup.FitToPagesTall" value="1" type="Double"/></columnFormats></table>');
INSERT INTO [dbo01].[TableFormats] ([TABLE_SCHEMA], [TABLE_NAME], [TABLE_EXCEL_FORMAT_XML]) VALUES (N'dbo67', N'Payments', '<table name="dbo67.Payments"><columnFormats><column name="" property="ListObjectName" value="Payments_Table1" type="String"/><column name="" property="ShowTotals" value="False" type="Boolean"/><column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String"/><column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean"/><column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean"/><column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean"/><column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean"/><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean"/><column name="_RowNum" property="Address" value="$B$4" type="String"/><column name="_RowNum" property="NumberFormat" value="General" type="String"/><column name="ID" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="ID" property="Address" value="$C$4" type="String"/><column name="ID" property="ColumnWidth" value="4.43" type="Double"/><column name="ID" property="NumberFormat" value="General" type="String"/><column name="ID" property="Validation.Type" value="1" type="Double"/><column name="ID" property="Validation.Operator" value="1" type="Double"/><column name="ID" property="Validation.Formula1" value="-2147483648" type="String"/><column name="ID" property="Validation.Formula2" value="2147483647" type="String"/><column name="ID" property="Validation.AlertStyle" value="1" type="Double"/><column name="ID" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="ID" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="ID" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="ID" property="Validation.ErrorMessage" value="The column requires values of the int datatype." type="String"/><column name="ID" property="Validation.ShowInput" value="True" type="Boolean"/><column name="ID" property="Validation.ShowError" value="True" type="Boolean"/><column name="Date" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="Date" property="Address" value="$D$4" type="String"/><column name="Date" property="ColumnWidth" value="10.71" type="Double"/><column name="Date" property="NumberFormat" value="m/d/yyyy" type="String"/><column name="Date" property="Validation.Type" value="4" type="Double"/><column name="Date" property="Validation.Operator" value="5" type="Double"/><column name="Date" property="Validation.Formula1" value="12/31/1899" type="String"/><column name="Date" property="Validation.AlertStyle" value="1" type="Double"/><column name="Date" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="Date" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="Date" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="Date" property="Validation.ErrorMessage" value="The column requires values of the datetime datatype." type="String"/><column name="Date" property="Validation.ShowInput" value="True" type="Boolean"/><column name="Date" property="Validation.ShowError" value="True" type="Boolean"/><column name="Sum" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="Sum" property="Address" value="$E$4" type="String"/><column name="Sum" property="ColumnWidth" value="11.43" type="Double"/><column name="Sum" property="NumberFormat" value="#,##0.00_);[Red](#,##0.00)" type="String"/><column name="Sum" property="Validation.Type" value="2" type="Double"/><column name="Sum" property="Validation.Operator" value="4" type="Double"/><column name="Sum" property="Validation.Formula1" value="-1.11222333444555E+29" type="String"/><column name="Sum" property="Validation.AlertStyle" value="1" type="Double"/><column name="Sum" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="Sum" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="Sum" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="Sum" property="Validation.ErrorMessage" value="The column requires values of the money datatype." type="String"/><column name="Sum" property="Validation.ShowInput" value="True" type="Boolean"/><column name="Sum" property="Validation.ShowError" value="True" type="Boolean"/><column name="AccountID" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="AccountID" property="Address" value="$F$4" type="String"/><column name="AccountID" property="ColumnWidth" value="9.71" type="Double"/><column name="AccountID" property="NumberFormat" value="General" type="String"/><column name="AccountID" property="Validation.Type" value="3" type="Double"/><column name="AccountID" property="Validation.Operator" value="1" type="Double"/><column name="AccountID" property="Validation.Formula1" value="=INDIRECT(&quot;vl_dbo67_Accounts[Name]&quot;)" type="String"/><column name="AccountID" property="Validation.Formula2" value="" type="String"/><column name="AccountID" property="Validation.AlertStyle" value="1" type="Double"/><column name="AccountID" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="AccountID" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="AccountID" property="Validation.ShowInput" value="True" type="Boolean"/><column name="AccountID" property="Validation.ShowError" value="True" type="Boolean"/><column name="CompanyID" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="CompanyID" property="Address" value="$G$4" type="String"/><column name="CompanyID" property="ColumnWidth" value="15.57" type="Double"/><column name="CompanyID" property="NumberFormat" value="General" type="String"/><column name="CompanyID" property="Validation.Type" value="3" type="Double"/><column name="CompanyID" property="Validation.Operator" value="1" type="Double"/><column name="CompanyID" property="Validation.Formula1" value="=INDIRECT(&quot;vl_dbo67_Companies[Name]&quot;)" type="String"/><column name="CompanyID" property="Validation.Formula2" value="" type="String"/><column name="CompanyID" property="Validation.AlertStyle" value="1" type="Double"/><column name="CompanyID" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="CompanyID" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="CompanyID" property="Validation.ShowInput" value="True" type="Boolean"/><column name="CompanyID" property="Validation.ShowError" value="True" type="Boolean"/><column name="ItemID" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="ItemID" property="Address" value="$H$4" type="String"/><column name="ItemID" property="ColumnWidth" value="9.29" type="Double"/><column name="ItemID" property="NumberFormat" value="General" type="String"/><column name="ItemID" property="Validation.Type" value="3" type="Double"/><column name="ItemID" property="Validation.Operator" value="1" type="Double"/><column name="ItemID" property="Validation.Formula1" value="=INDIRECT(&quot;vl_dbo67_Items[Name]&quot;)" type="String"/><column name="ItemID" property="Validation.Formula2" value="" type="String"/><column name="ItemID" property="Validation.AlertStyle" value="1" type="Double"/><column name="ItemID" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="ItemID" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="ItemID" property="Validation.ShowInput" value="True" type="Boolean"/><column name="ItemID" property="Validation.ShowError" value="True" type="Boolean"/><column name="Comment" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="Comment" property="Address" value="$I$4" type="String"/><column name="Comment" property="ColumnWidth" value="18.57" type="Double"/><column name="Comment" property="NumberFormat" value="General" type="String"/><column name="Comment" property="Validation.Type" value="6" type="Double"/><column name="Comment" property="Validation.Operator" value="8" type="Double"/><column name="Comment" property="Validation.Formula1" value="255" type="String"/><column name="Comment" property="Validation.AlertStyle" value="1" type="Double"/><column name="Comment" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="Comment" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="Comment" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="Comment" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(255) datatype." type="String"/><column name="Comment" property="Validation.ShowInput" value="True" type="Boolean"/><column name="Comment" property="Validation.ShowError" value="True" type="Boolean"/><column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean"/><column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean"/><column name="" property="ActiveWindow.Split" value="True" type="Boolean"/><column name="" property="ActiveWindow.SplitRow" value="0" type="Double"/><column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double"/><column name="" property="PageSetup.Orientation" value="1" type="Double"/><column name="" property="PageSetup.FitToPagesWide" value="1" type="Double"/><column name="" property="PageSetup.FitToPagesTall" value="1" type="Double"/></columnFormats><views><view name="All Payments"><column name="" property="ListObjectName" value="Payments_Table1" type="String"/><column name="" property="ShowTotals" value="False" type="Boolean"/><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean"/><column name="ID" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="Date" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="Sum" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="AccountID" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="CompanyID" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="ItemID" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="Comment" property="EntireColumn.Hidden" value="False" type="Boolean"/></view><view name="Incomes"><column name="" property="ListObjectName" value="Payments_Table1" type="String"/><column name="" property="ShowTotals" value="False" type="Boolean"/><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean"/><column name="ID" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="Date" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="Sum" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="AccountID" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="CompanyID" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="ItemID" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="Comment" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="Sum" property="AutoFilter.Criteria1" value="&gt;0" type="String"/></view><view name="Expenses"><column name="" property="ListObjectName" value="Payments_Table1" type="String"/><column name="" property="ShowTotals" value="False" type="Boolean"/><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean"/><column name="ID" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="Date" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="Sum" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="AccountID" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="CompanyID" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="ItemID" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="Comment" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="Sum" property="AutoFilter.Criteria1" value="&lt;0" type="String"/></view></views></table>');
INSERT INTO [dbo01].[TableFormats] ([TABLE_SCHEMA], [TABLE_NAME], [TABLE_EXCEL_FORMAT_XML]) VALUES (N'dbo67', N'uspPayments', '<table name="dbo67.uspPayments"><columnFormats><column name="" property="ListObjectName" value="Reports_Table1" type="String"/><column name="" property="ShowTotals" value="False" type="Boolean"/><column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String"/><column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean"/><column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean"/><column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean"/><column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean"/><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean"/><column name="_RowNum" property="Address" value="$B$4" type="String"/><column name="_RowNum" property="NumberFormat" value="General" type="String"/><column name="ID" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="ID" property="Address" value="$C$4" type="String"/><column name="ID" property="ColumnWidth" value="4.43" type="Double"/><column name="ID" property="NumberFormat" value="General" type="String"/><column name="Date" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="Date" property="Address" value="$D$4" type="String"/><column name="Date" property="ColumnWidth" value="10.71" type="Double"/><column name="Date" property="NumberFormat" value="m/d/yyyy" type="String"/><column name="Sum" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="Sum" property="Address" value="$E$4" type="String"/><column name="Sum" property="ColumnWidth" value="11.43" type="Double"/><column name="Sum" property="NumberFormat" value="#,##0.00_);[Red](#,##0.00)" type="String"/><column name="AccountID" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="AccountID" property="Address" value="$F$4" type="String"/><column name="AccountID" property="ColumnWidth" value="9.71" type="Double"/><column name="AccountID" property="NumberFormat" value="General" type="String"/><column name="AccountID" property="Validation.Type" value="3" type="Double"/><column name="AccountID" property="Validation.Operator" value="1" type="Double"/><column name="AccountID" property="Validation.Formula1" value="=INDIRECT(&quot;vl_dbo67_Accounts[Name]&quot;)" type="String"/><column name="AccountID" property="Validation.Formula2" value="" type="String"/><column name="AccountID" property="Validation.AlertStyle" value="1" type="Double"/><column name="AccountID" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="AccountID" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="AccountID" property="Validation.ShowInput" value="True" type="Boolean"/><column name="AccountID" property="Validation.ShowError" value="True" type="Boolean"/><column name="CompanyID" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="CompanyID" property="Address" value="$G$4" type="String"/><column name="CompanyID" property="ColumnWidth" value="15.57" type="Double"/><column name="CompanyID" property="NumberFormat" value="General" type="String"/><column name="CompanyID" property="Validation.Type" value="3" type="Double"/><column name="CompanyID" property="Validation.Operator" value="1" type="Double"/><column name="CompanyID" property="Validation.Formula1" value="=INDIRECT(&quot;vl_dbo67_Companies[Name]&quot;)" type="String"/><column name="CompanyID" property="Validation.Formula2" value="" type="String"/><column name="CompanyID" property="Validation.AlertStyle" value="1" type="Double"/><column name="CompanyID" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="CompanyID" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="CompanyID" property="Validation.ShowInput" value="True" type="Boolean"/><column name="CompanyID" property="Validation.ShowError" value="True" type="Boolean"/><column name="ItemID" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="ItemID" property="Address" value="$H$4" type="String"/><column name="ItemID" property="ColumnWidth" value="9.29" type="Double"/><column name="ItemID" property="NumberFormat" value="General" type="String"/><column name="ItemID" property="Validation.Type" value="3" type="Double"/><column name="ItemID" property="Validation.Operator" value="1" type="Double"/><column name="ItemID" property="Validation.Formula1" value="=INDIRECT(&quot;vl_dbo67_Items[Name]&quot;)" type="String"/><column name="ItemID" property="Validation.Formula2" value="" type="String"/><column name="ItemID" property="Validation.AlertStyle" value="1" type="Double"/><column name="ItemID" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="ItemID" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="ItemID" property="Validation.ShowInput" value="True" type="Boolean"/><column name="ItemID" property="Validation.ShowError" value="True" type="Boolean"/><column name="Comment" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="Comment" property="Address" value="$I$4" type="String"/><column name="Comment" property="ColumnWidth" value="18.57" type="Double"/><column name="Comment" property="NumberFormat" value="General" type="String"/><column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean"/><column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean"/><column name="" property="ActiveWindow.Split" value="True" type="Boolean"/><column name="" property="ActiveWindow.SplitRow" value="0" type="Double"/><column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double"/><column name="" property="PageSetup.Orientation" value="1" type="Double"/><column name="" property="PageSetup.FitToPagesWide" value="1" type="Double"/><column name="" property="PageSetup.FitToPagesTall" value="1" type="Double"/></columnFormats><views><view name="All Payments"><column name="" property="ListObjectName" value="Reports_Table1" type="String"/><column name="" property="ShowTotals" value="False" type="Boolean"/><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean"/><column name="ID" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="Date" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="Sum" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="AccountID" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="CompanyID" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="ItemID" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="Comment" property="EntireColumn.Hidden" value="False" type="Boolean"/></view><view name="Incomes"><column name="" property="ListObjectName" value="Reports_Table1" type="String"/><column name="" property="ShowTotals" value="False" type="Boolean"/><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean"/><column name="ID" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="Date" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="Sum" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="AccountID" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="CompanyID" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="ItemID" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="Comment" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="Sum" property="AutoFilter.Criteria1" value="&gt;0" type="String"/></view><view name="Expenses"><column name="" property="ListObjectName" value="Reports_Table1" type="String"/><column name="" property="ShowTotals" value="False" type="Boolean"/><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean"/><column name="ID" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="Date" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="Sum" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="AccountID" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="CompanyID" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="ItemID" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="Comment" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="Sum" property="AutoFilter.Criteria1" value="&lt;0" type="String"/></view></views></table>');
INSERT INTO [dbo01].[TableFormats] ([TABLE_SCHEMA], [TABLE_NAME], [TABLE_EXCEL_FORMAT_XML]) VALUES (N'dbo67', N'viewPayments', '<table name="dbo67.viewPayments"><columnFormats><column name="" property="ListObjectName" value="Reports_Table1" type="String"/><column name="" property="ShowTotals" value="False" type="Boolean"/><column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String"/><column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean"/><column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean"/><column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean"/><column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean"/><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean"/><column name="_RowNum" property="Address" value="$B$4" type="String"/><column name="_RowNum" property="NumberFormat" value="General" type="String"/><column name="ID" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="ID" property="Address" value="$C$4" type="String"/><column name="ID" property="ColumnWidth" value="4.43" type="Double"/><column name="ID" property="NumberFormat" value="General" type="String"/><column name="ID" property="Validation.Type" value="1" type="Double"/><column name="ID" property="Validation.Operator" value="1" type="Double"/><column name="ID" property="Validation.Formula1" value="-2147483648" type="String"/><column name="ID" property="Validation.Formula2" value="2147483647" type="String"/><column name="ID" property="Validation.AlertStyle" value="1" type="Double"/><column name="ID" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="ID" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="ID" property="Validation.ShowInput" value="True" type="Boolean"/><column name="ID" property="Validation.ShowError" value="True" type="Boolean"/><column name="Date" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="Date" property="Address" value="$D$4" type="String"/><column name="Date" property="ColumnWidth" value="10.57" type="Double"/><column name="Date" property="NumberFormat" value="m/d/yyyy" type="String"/><column name="Date" property="Validation.Type" value="4" type="Double"/><column name="Date" property="Validation.Operator" value="5" type="Double"/><column name="Date" property="Validation.Formula1" value="12/31/1899" type="String"/><column name="Date" property="Validation.AlertStyle" value="1" type="Double"/><column name="Date" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="Date" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="Date" property="Validation.ShowInput" value="True" type="Boolean"/><column name="Date" property="Validation.ShowError" value="True" type="Boolean"/><column name="Sum" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="Sum" property="Address" value="$E$4" type="String"/><column name="Sum" property="ColumnWidth" value="11.43" type="Double"/><column name="Sum" property="NumberFormat" value="#,##0.00_);[Red](#,##0.00)" type="String"/><column name="Sum" property="Validation.Type" value="2" type="Double"/><column name="Sum" property="Validation.Operator" value="4" type="Double"/><column name="Sum" property="Validation.Formula1" value="-1.11222333444555E+29" type="String"/><column name="Sum" property="Validation.AlertStyle" value="1" type="Double"/><column name="Sum" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="Sum" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="Sum" property="Validation.ShowInput" value="True" type="Boolean"/><column name="Sum" property="Validation.ShowError" value="True" type="Boolean"/><column name="AccountID" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="AccountID" property="Address" value="$F$4" type="String"/><column name="AccountID" property="ColumnWidth" value="9.71" type="Double"/><column name="AccountID" property="NumberFormat" value="General" type="String"/><column name="AccountID" property="Validation.Type" value="3" type="Double"/><column name="AccountID" property="Validation.Operator" value="1" type="Double"/><column name="AccountID" property="Validation.Formula1" value="=INDIRECT(&quot;vl_dbo67_Accounts[Name]&quot;)" type="String"/><column name="AccountID" property="Validation.Formula2" value="" type="String"/><column name="AccountID" property="Validation.AlertStyle" value="1" type="Double"/><column name="AccountID" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="AccountID" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="AccountID" property="Validation.ShowInput" value="True" type="Boolean"/><column name="AccountID" property="Validation.ShowError" value="True" type="Boolean"/><column name="CompanyID" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="CompanyID" property="Address" value="$G$4" type="String"/><column name="CompanyID" property="ColumnWidth" value="15.57" type="Double"/><column name="CompanyID" property="NumberFormat" value="General" type="String"/><column name="CompanyID" property="Validation.Type" value="3" type="Double"/><column name="CompanyID" property="Validation.Operator" value="1" type="Double"/><column name="CompanyID" property="Validation.Formula1" value="=INDIRECT(&quot;vl_dbo67_Companies[Name]&quot;)" type="String"/><column name="CompanyID" property="Validation.Formula2" value="" type="String"/><column name="CompanyID" property="Validation.AlertStyle" value="1" type="Double"/><column name="CompanyID" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="CompanyID" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="CompanyID" property="Validation.ShowInput" value="True" type="Boolean"/><column name="CompanyID" property="Validation.ShowError" value="True" type="Boolean"/><column name="ItemID" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="ItemID" property="Address" value="$H$4" type="String"/><column name="ItemID" property="ColumnWidth" value="11" type="Double"/><column name="ItemID" property="NumberFormat" value="General" type="String"/><column name="ItemID" property="Validation.Type" value="3" type="Double"/><column name="ItemID" property="Validation.Operator" value="1" type="Double"/><column name="ItemID" property="Validation.Formula1" value="=INDIRECT(&quot;vl_dbo67_Items[Name]&quot;)" type="String"/><column name="ItemID" property="Validation.Formula2" value="" type="String"/><column name="ItemID" property="Validation.AlertStyle" value="1" type="Double"/><column name="ItemID" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="ItemID" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="ItemID" property="Validation.ShowInput" value="True" type="Boolean"/><column name="ItemID" property="Validation.ShowError" value="True" type="Boolean"/><column name="Comment" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="Comment" property="Address" value="$I$4" type="String"/><column name="Comment" property="ColumnWidth" value="19.71" type="Double"/><column name="Comment" property="NumberFormat" value="General" type="String"/><column name="Comment" property="Validation.Type" value="6" type="Double"/><column name="Comment" property="Validation.Operator" value="8" type="Double"/><column name="Comment" property="Validation.Formula1" value="255" type="String"/><column name="Comment" property="Validation.AlertStyle" value="1" type="Double"/><column name="Comment" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="Comment" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="Comment" property="Validation.ShowInput" value="True" type="Boolean"/><column name="Comment" property="Validation.ShowError" value="True" type="Boolean"/><column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean"/><column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean"/><column name="" property="ActiveWindow.Split" value="True" type="Boolean"/><column name="" property="ActiveWindow.SplitRow" value="0" type="Double"/><column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double"/><column name="" property="PageSetup.Orientation" value="1" type="Double"/><column name="" property="PageSetup.FitToPagesWide" value="1" type="Double"/><column name="" property="PageSetup.FitToPagesTall" value="1" type="Double"/></columnFormats><views><view name="All Payments"><column name="" property="ListObjectName" value="Reports_Table1" type="String"/><column name="" property="ShowTotals" value="False" type="Boolean"/><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean"/><column name="ID" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="Date" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="Sum" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="AccountID" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="CompanyID" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="ItemID" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="Comment" property="EntireColumn.Hidden" value="False" type="Boolean"/></view><view name="Incomes"><column name="" property="ListObjectName" value="Reports_Table1" type="String"/><column name="" property="ShowTotals" value="False" type="Boolean"/><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean"/><column name="ID" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="Date" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="Sum" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="AccountID" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="CompanyID" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="ItemID" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="Comment" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="Sum" property="AutoFilter.Criteria1" value="&gt;0" type="String"/></view><view name="Expenses"><column name="" property="ListObjectName" value="Reports_Table1" type="String"/><column name="" property="ShowTotals" value="False" type="Boolean"/><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean"/><column name="ID" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="Date" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="Sum" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="AccountID" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="CompanyID" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="ItemID" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="Comment" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="Sum" property="AutoFilter.Criteria1" value="&lt;0" type="String"/></view></views></table>');
GO


SET IDENTITY_INSERT [dbo67].[Accounts] ON;
INSERT INTO [dbo67].[Accounts] ([ID], [Name]) VALUES (1, N'My Bank');
SET IDENTITY_INSERT [dbo67].[Accounts] OFF;
GO

SET IDENTITY_INSERT [dbo67].[Companies] ON;
INSERT INTO [dbo67].[Companies] ([ID], [Name]) VALUES (1, N'Carnation, Inc');
INSERT INTO [dbo67].[Companies] ([ID], [Name]) VALUES (2, N'Cornflower, Corp');
INSERT INTO [dbo67].[Companies] ([ID], [Name]) VALUES (3, N'Corporate Tax');
INSERT INTO [dbo67].[Companies] ([ID], [Name]) VALUES (4, N'Income Taxes');
INSERT INTO [dbo67].[Companies] ([ID], [Name]) VALUES (5, N'Land, Inc');
INSERT INTO [dbo67].[Companies] ([ID], [Name]) VALUES (6, N'Rose, Inc');
INSERT INTO [dbo67].[Companies] ([ID], [Name]) VALUES (7, N'Salary Taxes');
INSERT INTO [dbo67].[Companies] ([ID], [Name]) VALUES (8, N'Water, Inc');
SET IDENTITY_INSERT [dbo67].[Companies] OFF;
GO

SET IDENTITY_INSERT [dbo67].[Items] ON;
INSERT INTO [dbo67].[Items] ([ID], [Name]) VALUES (1, N'Expenses');
INSERT INTO [dbo67].[Items] ([ID], [Name]) VALUES (2, N'Payroll');
INSERT INTO [dbo67].[Items] ([ID], [Name]) VALUES (3, N'Revenue');
INSERT INTO [dbo67].[Items] ([ID], [Name]) VALUES (4, N'Taxes');
SET IDENTITY_INSERT [dbo67].[Items] OFF;
GO

SET IDENTITY_INSERT [dbo67].[Payments] ON;
INSERT INTO [dbo67].[Payments] ([ID], [Date], [Sum], [AccountID], [CompanyID], [ItemID]) VALUES (1, '20170110 00:00:00.000', 200000, 1, 6, 3);
INSERT INTO [dbo67].[Payments] ([ID], [Date], [Sum], [AccountID], [CompanyID], [ItemID]) VALUES (2, '20170110 00:00:00.000', -50000, 1, 5, 1);
INSERT INTO [dbo67].[Payments] ([ID], [Date], [Sum], [AccountID], [ItemID]) VALUES (3, '20170131 00:00:00.000', -87000, 1, 2);
INSERT INTO [dbo67].[Payments] ([ID], [Date], [Sum], [AccountID], [CompanyID], [ItemID]) VALUES (4, '20170131 00:00:00.000', -13000, 1, 4, 4);
INSERT INTO [dbo67].[Payments] ([ID], [Date], [Sum], [AccountID], [CompanyID], [ItemID]) VALUES (5, '20170131 00:00:00.000', -29580, 1, 7, 4);
INSERT INTO [dbo67].[Payments] ([ID], [Date], [Sum], [AccountID], [CompanyID], [ItemID]) VALUES (6, '20170210 00:00:00.000', 300000, 1, 6, 3);
INSERT INTO [dbo67].[Payments] ([ID], [Date], [Sum], [AccountID], [CompanyID], [ItemID]) VALUES (7, '20170210 00:00:00.000', 100000, 1, 1, 3);
INSERT INTO [dbo67].[Payments] ([ID], [Date], [Sum], [AccountID], [CompanyID], [ItemID]) VALUES (8, '20170210 00:00:00.000', -50000, 1, 8, 1);
INSERT INTO [dbo67].[Payments] ([ID], [Date], [Sum], [AccountID], [CompanyID], [ItemID]) VALUES (9, '20170210 00:00:00.000', -100000, 1, 5, 1);
INSERT INTO [dbo67].[Payments] ([ID], [Date], [Sum], [AccountID], [ItemID]) VALUES (10, '20170228 00:00:00.000', -87000, 1, 2);
INSERT INTO [dbo67].[Payments] ([ID], [Date], [Sum], [AccountID], [CompanyID], [ItemID]) VALUES (11, '20170228 00:00:00.000', -13000, 1, 4, 4);
INSERT INTO [dbo67].[Payments] ([ID], [Date], [Sum], [AccountID], [CompanyID], [ItemID]) VALUES (12, '20170228 00:00:00.000', -29580, 1, 7, 4);
INSERT INTO [dbo67].[Payments] ([ID], [Date], [Sum], [AccountID], [CompanyID], [ItemID]) VALUES (13, '20170310 00:00:00.000', 300000, 1, 6, 3);
INSERT INTO [dbo67].[Payments] ([ID], [Date], [Sum], [AccountID], [CompanyID], [ItemID]) VALUES (14, '20170310 00:00:00.000', 200000, 1, 1, 3);
INSERT INTO [dbo67].[Payments] ([ID], [Date], [Sum], [AccountID], [CompanyID], [ItemID]) VALUES (15, '20170310 00:00:00.000', 100000, 1, 2, 3);
INSERT INTO [dbo67].[Payments] ([ID], [Date], [Sum], [AccountID], [CompanyID], [ItemID]) VALUES (16, '20170315 00:00:00.000', -36000, 1, 3, 4);
INSERT INTO [dbo67].[Payments] ([ID], [Date], [Sum], [AccountID], [ItemID]) VALUES (17, '20170331 00:00:00.000', -174000, 1, 2);
INSERT INTO [dbo67].[Payments] ([ID], [Date], [Sum], [AccountID], [CompanyID], [ItemID]) VALUES (18, '20170331 00:00:00.000', -26000, 1, 4, 4);
INSERT INTO [dbo67].[Payments] ([ID], [Date], [Sum], [AccountID], [CompanyID], [ItemID]) VALUES (19, '20170331 00:00:00.000', -59160, 1, 7, 4);
INSERT INTO [dbo67].[Payments] ([ID], [Date], [Sum], [AccountID], [CompanyID], [ItemID]) VALUES (20, '20170331 00:00:00.000', -50000, 1, 8, 1);
INSERT INTO [dbo67].[Payments] ([ID], [Date], [Sum], [AccountID], [CompanyID], [ItemID]) VALUES (21, '20170331 00:00:00.000', -100000, 1, 5, 1);
SET IDENTITY_INSERT [dbo67].[Payments] OFF;
GO


print N'The application has been installed';
GO
