Attribute VB_Name = "ten_steps"
Option Explicit

' ===================================================================
' SaveToDB add-in functions
' ===================================================================

' Returns the SaveToDB addin object

Private AddInObject As Object

Function GetAddIn() As Object

    On Error Resume Next

    If AddInObject Is Nothing Then
    
        Dim addIn As COMAddIn
        Set addIn = Application.COMAddIns("SaveToDB")
        
        If addIn Is Nothing Then Exit Function
            
        Set AddInObject = addIn.Object
    
    End If
    
    Set GetAddIn = AddInObject

End Function

' Returns the SaveToDB addin object and shows an error message

Function GetAddInAndCheck() As Object

    Set GetAddInAndCheck = GetAddIn()
    
    If GetAddInAndCheck Is Nothing Then
        Debug.Print "Install the SaveToDB add-in"
        MsgBox "Install the SaveToDB add-in." & vbCrLf _
             & "You may download it at www.savetodb.com"
    End If

End Function

' Inserts a connected ListObject object at the specified range

Function InsertConnectedListObject(ByVal addIn As Object, ByVal r As Range, _
    ByVal connString As String, ByVal commandText As String, ByVal objectType As String, _
    Optional queryListLocked As Boolean = False) As Boolean

    If addIn Is Nothing Then Set addIn = GetAddIn()
    If addIn Is Nothing Then Exit Function
    
    InsertConnectedListObject = addIn.InsertConnectedListObject(r, connString, commandText, objectType)

    If Not InsertConnectedListObject Then
        Debug.Print addIn.LastResultMessage
        Exit Function
    End If

    If Not queryListLocked Then Exit Function
    
    Dim lo As ListObject
    Set lo = r.ListObject

    addIn.QueryLocked(lo) = queryListLocked

End Function

' Saves the changes of the active ListObject

Sub Save()

    Dim lo As ListObject
    Set lo = GetActiveListObject()
    
    If lo Is Nothing Then Exit Sub

    Call SaveListObject(lo)

End Sub

' Reloads data of the active ListObject

Sub Load()

    Dim lo As ListObject
    Set lo = GetActiveListObject()
    
    If lo Is Nothing Then Exit Sub

    Call LoadListObject(lo, False)

End Sub

' Reloads data and configuration of the active ListObject

Sub LoadDataAndConfiguration()

    Dim lo As ListObject
    Set lo = GetActiveListObject()
    
    If lo Is Nothing Then Exit Sub

    Call LoadListObject(lo, True)

End Sub

' Saves the changes of the ListObject object to a database

Function SaveListObject(ByVal lo As ListObject, Optional ByVal addIn As Object) As Boolean

    If addIn Is Nothing Then Set addIn = GetAddIn()
    If addIn Is Nothing Then Exit Function
    
    SaveListObject = addIn.Save(lo)

    If Not SaveListObject Then
        Debug.Print addIn.LastResultMessage
    End If

End Function

' Reloads the ListObject data from a database

Function LoadListObject(ByVal lo As ListObject, ByVal reloadConfiguraton As Boolean, Optional ByVal addIn As Object) As Boolean

    If addIn Is Nothing Then Set addIn = GetAddIn()
    If addIn Is Nothing Then Exit Function
    
    LoadListObject = addIn.Load(lo, reloadConfiguraton)

    If Not LoadListObject Then
        Debug.Print addIn.LastResultMessage
    End If

End Function

' Moves the table cursor to the first record

Sub MoveToFirst()

    Dim addIn As Object
    Set addIn = GetAddInAndCheck()
    
    If addIn Is Nothing Then Exit Sub
   
    Call addIn.MoveFirst

End Sub

' Moves the table cursor to the previous record

Sub MoveToPrev()

    Dim addIn As Object
    Set addIn = GetAddInAndCheck()
    
    If addIn Is Nothing Then Exit Sub
    
    Call addIn.MovePrevious

End Sub

' Moves the table cursor to the next record

Sub MoveToNext()

    Dim addIn As Object
    Set addIn = GetAddInAndCheck()
    
    If addIn Is Nothing Then Exit Sub
    
    Call addIn.MoveNext

End Sub

' Moves the table cursor to the last record

Sub MoveToLast()

    Dim addIn As Object
    Set addIn = GetAddInAndCheck()
    
    If addIn Is Nothing Then Exit Sub
    
    Call addIn.MoveLast

End Sub


' ===================================================================
' Connection functions
' ===================================================================

' Returns a connection string

Function GetConnectionString() As String
       
    GetConnectionString = OleDbConnectionString("ko7h266q17.database.windows.net", "AzureDemo50", "Payments67_Developer", "Dev_2011#_Xls4168")
    ' GetConnectionString = OdbcConnectionString("ko7h266q17.database.windows.net", "AzureDemo50", "Payments67_Developer", "Dev_2011#_Xls4168")
    
    ' GetConnectionString = OleDbConnectionString(".\SQLEXPRESS", "Test", "", "")
    ' GetConnectionString = OdbcConnectionString(".\SQLEXPRESS", "Test", "", "")

End Function

' Returns an OLEDB connection string

Function OleDbConnectionString(ByVal server As String, ByVal database As String, _
    ByVal username As String, ByVal password As String) As String

    If username = "" Then
        OleDbConnectionString = "Provider=SQLOLEDB;Data Source=" & server _
            & ";Initial Catalog=" & database _
            & ";Integrated Security=SSPI;Persist Security Info=False;"
    Else
        OleDbConnectionString = "Provider=SQLOLEDB;Data Source=" & server _
            & ";Initial Catalog=" & database _
            & ";User ID=" & username & ";Password=" & password & ";"
    End If

End Function

' Returns an ODBC connection string

Function OdbcConnectionString(ByVal server As String, ByVal database As String, _
    ByVal username As String, ByVal password As String) As String

    If username = "" Then
        OdbcConnectionString = "Driver={SQL Server};Server=" & server _
            & ";Trusted_Connection=Yes;Database=" & database
    Else
        OdbcConnectionString = "Driver={SQL Server};Server=" & server _
            & ";UID=" & username & ";PWD=" & password & ";Database=" & database
    End If

End Function

' Converts a string value to an array

Function StringToArray(Str As String) As Variant

    Const strLen = 127
    Dim numElems As Integer
    Dim temp() As String
    Dim i As Integer
    
    numElems = (Len(Str) / strLen) + 1
    ReDim temp(1 To numElems) As String
    
    For i = 1 To numElems
       temp(i) = Mid(Str, ((i - 1) * strLen) + 1, strLen)
    Next i
    
    StringToArray = temp

End Function


' ===================================================================
' Common worksheet functions
' ===================================================================

' Adds a worksheet

Function AddWorksheet(ByVal wb As Workbook, ByVal sheetName As String) As Worksheet

    Dim ws As Worksheet
    
    Set ws = wb.Sheets.Add(after:=wb.Sheets(wb.Sheets.Count))
    
    ws.Name = sheetName
    
    Set AddWorksheet = ws

End Function

' Returns a worksheet or Nothing

Function GetWorksheet(ByVal wb As Workbook, ByVal sheetName As String) As Worksheet

    Dim ws As Worksheet
    
    For Each ws In wb.Worksheets
        If StrComp(ws.Name, sheetName, 1) = 0 Then
            Set GetWorksheet = ws
            Exit Function
        End If
    Next
    
    Set GetWorksheet = Nothing

End Function

' Returns a worksheet, creates if not exists

Function GetOrCreateWorksheet(ByVal wb As Workbook, ByVal sheetName As String) As Worksheet

    Set GetOrCreateWorksheet = GetWorksheet(wb, sheetName)
    
    If Not GetOrCreateWorksheet Is Nothing Then Exit Function

    Set GetOrCreateWorksheet = AddWorksheet(wb, sheetName)

End Function

' Deletes a worksheet

Sub DeleteWorksheet(ByVal wb As Workbook, ByVal sheetName As String)

    Dim ws As Worksheet
    Set ws = GetWorksheet(wb, sheetName)
    
    If ws Is Nothing Then Exit Sub

    On Error Resume Next

    Application.DisplayAlerts = False

    ws.Delete

    Application.DisplayAlerts = True

End Sub


' ===================================================================
' Common ListObject functions
' ===================================================================

' Returns the first ListObject at the worksheet

Function GetFirstListObject(ByVal ws As Worksheet) As ListObject

    If ws.ListObjects.Count = 0 Then
        Debug.Print "There are no ListObjects at " + ws.Name
        Set GetFirstListObject = Nothing
        Exit Function
    End If

    Set GetFirstListObject = ws.ListObjects(1)
   
End Function

' Returns the active ListObject

Function GetActiveListObject() As ListObject

    Set GetActiveListObject = ActiveCell.ListObject

    If Not GetActiveListObject Is Nothing Then Exit Function

    If ActiveSheet.ListObjects.Count <> 1 Then Exit Function
    
    Set GetActiveListObject = ActiveSheet.ListObjects(1)

End Function


' ===================================================================
' App specific worksheet functions
' ===================================================================

' Returns a worksheet, creates if not exists, and inserts a connected table
 
Function GetOrCreateConnectedWorksheet(ByVal wb As Workbook, ByVal sheetName, _
    ByVal connString As String, ByVal commandText As String, ByVal objectType As String, _
    Optional queryListLocked As Boolean = False) As Worksheet
    
    Dim ws As Worksheet
    Set ws = GetOrCreateWorksheet(wb, sheetName)
        
    Set GetOrCreateConnectedWorksheet = ws

    If ws.ListObjects.Count > 0 Then Exit Function
    
    Dim r As Range
    Set r = ws.Range("B3")
    
    If Not InsertConnectedListObject(Nothing, r, connString, commandText, objectType, queryListLocked) Then
        Exit Function
    End If

End Function


' ===================================================================
' App specific button functions
' ===================================================================

' Adds Save and Load buttons

Sub AddSaveAndLoadButtons(ByVal ws As Worksheet)
    
    If ws.Buttons.Count > 0 Then Exit Sub
   
    With ws.Buttons.Add(204, 4, 72, 18)
        .Name = "Save"
        .Caption = "Save"
        .OnAction = "Save"
    End With

    With ws.Buttons.Add(278, 4, 72, 18)
        .Name = "Load"
        .Caption = "Load"
        .OnAction = "Load"
    End With

End Sub

' Adds cursors buttons

Sub AddCursorButtons(ByVal ws As Worksheet)
    
    If ws.Buttons.Count > 2 Then Exit Sub
    
    With ws.Buttons.Add(360, 4, 36, 18)
        .Name = "MoveToFirst"
        .Caption = "|<"
        .OnAction = "MoveToFirst"
    End With

    With ws.Buttons.Add(398, 4, 36, 18)
        .Name = "MoveToPrev"
        .Caption = "<"
        .OnAction = "MoveToPrev"
    End With

    With ws.Buttons.Add(436, 4, 36, 18)
        .Name = "MoveToNext"
        .Caption = ">"
        .OnAction = "MoveToNext"
    End With

    With ws.Buttons.Add(474, 4, 36, 18)
        .Name = "MoveToLast"
        .Caption = ">|"
        .OnAction = "MoveToLast"
    End With

End Sub


' ===================================================================
' Chapter examples
' ===================================================================

' Inserts the dbo67.Companies table to range B3
' The code demonstrates the simplest way to insert a connected table
' The dummy parameter is used to prevent showing the procedure in a macro list

Sub Chapter02_1_InsertConnectedListObject(ByVal dummy As Boolean)

    Dim connString As String
    
    connString = "Provider=SQLOLEDB.1;Data Source=.\SQLEXPRESS;Initial Catalog=Test"

    InsertConnectedListObject Nothing, Range("B3"), connString, "dbo67.Companies", "TABLE"

End Sub


' Creates master table editors, Chapter 2

Sub Chapter02_2_CreateMasterTableEditors()

    Dim addIn As Object
    Set addIn = GetAddInAndCheck()

    If addIn Is Nothing Then Exit Sub

    Dim wb As Workbook
    Set wb = ActiveWorkbook
    ' Set wb = Workbooks.Add(ActiveWorkbook.FullName)

    Call addIn.InsertAddInSheets(wb)
    
    Dim connString As String
    connString = GetConnectionString()

    Dim ws As Worksheet
    Set ws = GetOrCreateConnectedWorksheet(wb, "Companies", connString, "dbo67.Companies", "TABLE", True)
    
    If ws Is Nothing Then Exit Sub
    
    Call GetOrCreateConnectedWorksheet(wb, "Items", connString, "dbo67.Items", "TABLE", True)
    Call GetOrCreateConnectedWorksheet(wb, "Accounts", connString, "dbo67.Accounts", "TABLE", True)

    ws.Select

End Sub


' Creates the Payments worksheet, Chapter 5

Sub Chapter05_1_CreatePaymentsWorksheet()

    Dim addIn As Object
    Set addIn = GetAddInAndCheck()

    If addIn Is Nothing Then Exit Sub

    Dim wb As Workbook
    Set wb = ActiveWorkbook

    Call addIn.InsertAddInSheets(wb)
    
    Dim connString As String
    connString = GetConnectionString()

    Dim ws As Worksheet
    Set ws = GetOrCreateConnectedWorksheet(wb, "Payments", connString, "dbo67.Payments", "TABLE", True)

    ws.Select

End Sub


' Configures WHERE parameters of the Payments table, Chapter 6

Sub Chapter06_1_SetPaymentsWhereParameters()

    Dim addIn As Object
    Set addIn = GetAddInAndCheck()

    If addIn Is Nothing Then Exit Sub

    Dim ws As Worksheet
    Set ws = GetWorksheet(ActiveWorkbook, "Payments")
    
    If ws Is Nothing Then
        MsgBox "Worksheet Payments not exists"
        Exit Sub
    End If

    ws.Select

    Dim lo As ListObject
    Set lo = GetFirstListObject(ws)

    If lo Is Nothing Then
        MsgBox "Worksheet Payments does not contain a table"
        Exit Sub
    End If
    
    addIn.IsRibbonField(lo, "AccountID") = True
    addIn.IsRibbonField(lo, "CompanyID") = True
    addIn.IsRibbonField(lo, "ItemID") = True
    
    ' Use ParameterValue to set id values
    ' addIn.ParameterValue(lo, "AccountID") = Nothing
    ' addIn.ParameterValue(lo, "CompanyID") = Nothing
    ' addIn.ParameterValue(lo, "ItemID") = Nothing
    
    ' Use ParameterRibbonValue to set name values
    ' addIn.ParameterRibbonValue(lo, "AccountID") = Nothing
    ' addIn.ParameterRibbonValue(lo, "CompanyID") = Nothing
    ' addIn.ParameterRibbonValue(lo, "ItemID") = Nothing

End Sub


' Sets a new language and reloads data and configurations, Chapter 7

Sub Chapter07_1_SetLanguage()

    Dim addIn As Object
    Set addIn = GetAddInAndCheck()

    If addIn Is Nothing Then Exit Sub

    addIn.Options.DefaultDataLanguage = "en-US"

    Dim ws As Worksheet
    
    For Each ws In ActiveWorkbook.Worksheets
        Call addIn.LoadAllSheetTables(ws, True)
    Next

End Sub


' Creating table views, Chapter 9

Sub Chapter09_1_CreateTableViews()

    Dim addIn As Object
    Set addIn = GetAddInAndCheck()

    If addIn Is Nothing Then Exit Sub

    Dim ws As Worksheet
    Set ws = GetWorksheet(ActiveWorkbook, "Payments")
    
    If ws Is Nothing Then
        MsgBox "Worksheet Payments not exists"
        Exit Sub
    End If

    ws.Select

    Dim lo As ListObject
    Set lo = GetFirstListObject(ws)

    If lo Is Nothing Then
        MsgBox "Worksheet Payments does not contain a table"
        Exit Sub
    End If
    
    Dim cell As Range
    Set cell = ws.Range("E2")
    
    Call addIn.SaveTableView(lo, "All Payments")
    
    cell.Value = ">0"
    
    Call addIn.SaveTableView(lo, "Incomes")
    
    cell.Value = "<0"
    
    Call addIn.SaveTableView(lo, "Expenses")
    
    cell.ClearContents
    
    Call addIn.ApplyTableView(lo, "Incomes")

End Sub


' Creates the Reports worksheet, Chapter 11

Sub Chapter11_1_CreateReportsWorksheet()

    Dim addIn As Object
    Set addIn = GetAddInAndCheck()

    If addIn Is Nothing Then Exit Sub

    Dim wb As Workbook
    Set wb = ActiveWorkbook

    Call addIn.InsertAddInSheets(wb)
    
    Dim connString As String
    connString = GetConnectionString()

    Dim ws As Worksheet
    Set ws = GetOrCreateConnectedWorksheet(wb, "Reports", connString, "dbo67.viewPayments", "VIEW", True)

    If ws Is Nothing Then Exit Sub

    ws.Select

    Dim lo As ListObject
    Set lo = GetFirstListObject(ws)

    If lo Is Nothing Then Exit Sub
    
    addIn.QueryList(lo) = "xls01.viewQueryList"
    addIn.QueryLocked(lo) = False
    
    Call addIn.ReloadQueryList(lo)
    
    addIn.IsRibbonField(lo, "AccountID") = True
    addIn.IsRibbonField(lo, "CompanyID") = True
    addIn.IsRibbonField(lo, "ItemID") = True
    
    ' Use ParameterValue to set id values
    ' addIn.ParameterValue(lo, "AccountID") = Nothing
    ' addIn.ParameterValue(lo, "CompanyID") = Nothing
    ' addIn.ParameterValue(lo, "ItemID") = Nothing
    
    ' Use ParameterRibbonValue to set name values
    ' addIn.ParameterRibbonValue(lo, "AccountID") = Nothing
    ' addIn.ParameterRibbonValue(lo, "CompanyID") = Nothing
    ' addIn.ParameterRibbonValue(lo, "ItemID") = Nothing

End Sub


' Changing queries using Query List, Chapter 13

Sub Chapter13_1_ChangeQueryObject()

    Dim addIn As Object
    Set addIn = GetAddInAndCheck()

    If addIn Is Nothing Then Exit Sub

    Dim ws As Worksheet
    Set ws = GetWorksheet(ActiveWorkbook, "Reports")
    
    If ws Is Nothing Then
        MsgBox "Worksheet Reports not exists"
        Exit Sub
    End If

    Dim lo As ListObject
    Set lo = GetFirstListObject(ws)

    If lo Is Nothing Then
        MsgBox "Worksheet Reports does not contain a table"
        Exit Sub
    End If
    
    Call addIn.ReloadQueryList(lo)
    
    addIn.QueryObject(lo) = "dbo67.uspPayments"

End Sub


' Saving changes, Chapter 14

Sub Chapter14_1_SaveChanges()

    Dim addIn As Object
    Set addIn = GetAddInAndCheck()

    If addIn Is Nothing Then Exit Sub

    Dim lo As ListObject
    Set lo = GetActiveListObject()

    If lo Is Nothing Then Exit Sub
    
    If Not addIn.Save(lo) Then
        Debug.Print addIn.LastResultMessage
    End If

End Sub


' Adding cursors, Chapter 15

Sub Chapter15_1_AddCursors()

    Dim addIn As Object
    Set addIn = GetAddInAndCheck()

    If addIn Is Nothing Then Exit Sub

    Dim ws As Worksheet
    Set ws = GetWorksheet(ActiveWorkbook, "Payments")
    
    If ws Is Nothing Then
        MsgBox "Worksheet Payments not exists"
        Exit Sub
    End If

    ws.Select
    
    Dim lo As ListObject
    Set lo = GetActiveListObject()

    If lo Is Nothing Then
        MsgBox "Worksheet Payments does not contain a table"
        Exit Sub
    End If
    
    ' Call addIn.RemoveTableCursor(lo)
    Call addIn.AddTableCursor(lo)

End Sub

' Adding cursor buttons, Chapter 15

Sub Chapter15_2_AddCursorButtons()

    Dim ws As Worksheet
    Set ws = GetWorksheet(ActiveWorkbook, "Payments")
    
    If ws Is Nothing Then
        MsgBox "Worksheet Payments not exists"
        Exit Sub
    End If

    ws.Select
    
    Call AddSaveAndLoadButtons(ws)
    Call AddCursorButtons(ws)

End Sub


' Adding form fields, Chapter 16

Sub Chapter16_1_AddFormFields()

    Dim addIn As Object
    Set addIn = GetAddInAndCheck()

    If addIn Is Nothing Then Exit Sub

    Dim ws As Worksheet
    Set ws = GetWorksheet(ActiveWorkbook, "Payments")
    
    If ws Is Nothing Then
        MsgBox "Worksheet Payments not exists"
        Exit Sub
    End If

    ws.Select
    
    Dim lo As ListObject
    Set lo = GetFirstListObject(ActiveSheet)

    If lo Is Nothing Then
        MsgBox "Worksheet Payments does not contain a table"
        Exit Sub
    End If
    
    ' Call addIn.RemoveFormFields(lo)
    Call addIn.AddFormFields(lo, Range("K4"))

End Sub


' Creating master-details, Chapter 17

Sub Chapter17_1_CreateCompanyPaymentsWorksheet()

    Dim addIn As Object
    Set addIn = GetAddInAndCheck()

    If addIn Is Nothing Then Exit Sub

    Dim wb As Workbook
    Set wb = ActiveWorkbook

    Call addIn.InsertAddInSheets(wb)
    
    Dim connString As String
    connString = GetConnectionString()

    Dim ws As Worksheet
    Set ws = GetOrCreateWorksheet(wb, "CompanyPayments")
    
    ws.Select
    
    If ws.ListObjects.Count > 0 Then
        MsgBox "Worksheet CompanyPayments already has tables"
        Exit Sub
    End If
    
    Call InsertConnectedListObject(addIn, Range("B3"), connString, "dbo67.Companies", "TABLE", True)
    
    If ws.ListObjects.Count < 1 Then Exit Sub
    
    Call InsertConnectedListObject(addIn, Range("F3"), connString, "dbo67.viewPayments", "VIEW", True)

    If ws.ListObjects.Count < 2 Then Exit Sub
    
    Dim lo As ListObject
    Set lo = ws.ListObjects(1)
    
    Call addIn.AddTableCursor(lo)
    
    Dim fieldIdName As String
    fieldIdName = addIn.GetFormFieldCellName(lo, "ID")
    
    Dim fieldNameName As String
    fieldNameName = addIn.GetFormFieldCellName(lo, "Name")
    
    ws.Names.Add Name:=fieldIdName, RefersTo:=Range("C1")
    ws.Names.Add Name:=fieldNameName, RefersTo:=Range("D1")
    
    Set lo = ws.ListObjects(2)
    
    addIn.IsRibbonField(lo, "AccountID") = False
    addIn.IsRibbonField(lo, "CompanyID") = True
    addIn.IsRibbonField(lo, "ItemID") = False
    
    ' Set the initial value using ID from cell C1 (or using Name from cell D1)
    
    addIn.ParameterValue(lo, "CompanyID") = Range("C1").Value
    ' addIn.ParameterRibbonValue(lo, "CompanyID") = Range("D1").Value
    
    ws.Names.Add Name:="CompanyID", RefersTo:=Range("C1")
    
    ' Cell C1 must have two names: field_CompanyPayments_Table1_ID and CompanyID

    ws.Range("D4").Select

End Sub


' Creates the application worksheets, Chapter 21

Sub Chapter21_1_CreateApplication()

    Call Chapter02_2_CreateMasterTableEditors
    Call Chapter05_1_CreatePaymentsWorksheet
    Call Chapter06_1_SetPaymentsWhereParameters
    Call Chapter07_1_SetLanguage
    Call Chapter09_1_CreateTableViews
    Call Chapter11_1_CreateReportsWorksheet
    Call Chapter13_1_ChangeQueryObject
    Call Chapter14_1_SaveChanges
    Call Chapter15_1_AddCursors
    Call Chapter15_2_AddCursorButtons
    Call Chapter16_1_AddFormFields
    Call Chapter17_1_CreateCompanyPaymentsWorksheet

End Sub

' Removes the application worksheets, Chapter 21

Sub Chapter21_2_RemoveApplication()

    If Not MsgBox("Are you sure to delete all worksheets?", vbYesNo) = vbYes Then Exit Sub
  
    Dim wb As Workbook
    Set wb = ActiveWorkbook

    Call DeleteWorksheet(wb, "CompanyPayments")
    Call DeleteWorksheet(wb, "Reports")
    Call DeleteWorksheet(wb, "Payments")
    Call DeleteWorksheet(wb, "Accounts")
    Call DeleteWorksheet(wb, "Companies")
    Call DeleteWorksheet(wb, "Items")
    
    Dim addIn As Object
    Set addIn = GetAddInAndCheck()

    If addIn Is Nothing Then Exit Sub
    
    Call addIn.DeleteAllTableViews(wb)
    
    Call addIn.DeleteAllTableCursors(wb)
    
    Call addIn.DeleteAddInSheets(wb)

    ' The workbook must contain the start sheet only

End Sub

